@@ -1,8 +1,9 @@
 {{SLASH_COMMENTS}}
 
-#include "image_provider.h"
 #include <QDebug>
 
+#include "image_provider.h"
+
 QmlImageProvider::QmlImageProvider()
     : QQuickImageProvider(QQuickImageProvider::Image) {
 }
@@ -13,6 +14,12 @@ void QmlImageProvider::updateImage(int index, const QImage &image) {
     images[index] = image;
 }
 
+void QmlImageProvider::deleteImage(int index) {
+    qDebug() << "provider: delete" << index;
+    QMutexLocker lock(&mutex);
+    images.remove(index);
+}
+
 QImage QmlImageProvider::requestImage(const QString &id, QSize *size, const QSize &requestedSize) {
     qDebug() << "provider: request id" << id;
     int index = id.leftRef(id.indexOf("###")).toInt();
